@@ -1,34 +1,12 @@
 import json
-from functools import wraps
 from time import time
 from ..exceptions.sdk_exception import OpenLISAException
 from ..exceptions.invalid_command import InvalidCommandException
 from ...logging import log
 
-# Source: https://stackoverflow.com/questions/1622943/timeit-versus-timing-decorator
-def with_latency_logs(f):
-  @wraps(f)
-  def wrap(*args, **kw):
-    entering(f)
-    ts = time()
-    result = f(*args, **kw)
-    te = time()
-    exiting(f, te-ts)
-    return result
-  return wrap
-
-def entering(func):
-	""" Pre function logging """
-	log.debug("[LATENCY_MEASURE][INIT][{}]".format(func.__name__))
-
-def exiting(func, elapsed):
-	""" Post function logging """
-	log.debug("[LATENCY_MEASURE][FINISH][{}][ELAPSED={.8f} seconds]".format(func.__name__, elapsed))
-
 SUCCESS_RESPONSE = "OK"
 ERROR_RESPONSE = "ERROR"
 
-
 COMMAND_GET_INSTRUMENTS = "GET_INSTRUMENTS"
 COMMAND_GET_INSTRUMENT = "GET_INSTRUMENT"
 COMMAND_GET_INSTRUMENT_COMMANDS = "GET_INSTRUMENT_COMMANDS"
@@ -47,44 +25,62 @@ class ClientProtocol:
 
     raise Exception("unknown response type: '{}'".format(response))
 
-  @with_latency_logs()
   def get_instruments(self):
-    log.debug('')
+    log.debug("[LATENCY_MEASURE][INIT][{}]".format('get_instruments'))
+    ts = time()
     self._message_protocol.send_msg(COMMAND_GET_INSTRUMENTS)
-    return json.loads(self._message_protocol.receive_msg())
+    result = self._message_protocol.receive_msg()
+    te = time()
+    log.debug("[LATENCY_MEASURE][FINISH][{}][ELAPSED={.8f} seconds]".format('get_instruments', te-ts))
+    return json.loads(result)
 
-  @with_latency_logs()
   def get_instrument(self, id):
+    log.debug("[LATENCY_MEASURE][INIT][{}]".format('get_instrument'))
+    ts = time()
     self._message_protocol.send_msg(COMMAND_GET_INSTRUMENT)
     self._message_protocol.send_msg(id)
     response_type = self._message_protocol.receive_msg()
+    result_msg = self._message_protocol.receive_msg()
+    te = time()
+    log.debug("[LATENCY_MEASURE][FINISH][{}][ELAPSED={.8f} seconds]".format('get_instrument', te-ts))
     if self.__is_valid_response(response_type):
-      return json.loads(self._message_protocol.receive_msg())
+      return json.loads(result_msg)
     else:
-      raise OpenLISAException(self._message_protocol.receive_msg())
+      raise OpenLISAException(result_msg)
 
-  @with_latency_logs()
   def get_instrument_commands(self, id):
+    log.debug("[LATENCY_MEASURE][INIT][{}]".format('get_instrument_commands'))
+    ts = time()
     self._message_protocol.send_msg(COMMAND_GET_INSTRUMENT_COMMANDS)
     self._message_protocol.send_msg(id)
     response_type = self._message_protocol.receive_msg()
+    result_msg = self._message_protocol.receive_msg()
+    te = time()
+    log.debug("[LATENCY_MEASURE][FINISH][{}][ELAPSED={.8f} seconds]".format('get_instrument_commands', te-ts))
     if self.__is_valid_response(response_type):
-      return json.loads(self._message_protocol.receive_msg())
+      return json.loads(result_msg)
     else:
-      raise OpenLISAException(self._message_protocol.receive_msg())
+      raise OpenLISAException(result_msg)
 
-  @with_latency_logs()
   def validate_command(self, id, command):
+    log.debug("[LATENCY_MEASURE][INIT][{}]".format('validate_command'))
+    ts = time()
     self._message_protocol.send_msg(COMMAND_VALIDATE_COMMAND)
     self._message_protocol.send_msg(id)
     self._message_protocol.send_msg(command)
     response_type = self._message_protocol.receive_msg()
     if not self.__is_valid_response(response_type):
       err = self._message_protocol.receive_msg()
+      te = time()
+      log.debug("[LATENCY_MEASURE][FINISH][{}][ELAPSED={.8f} seconds]".format('validate_command', te-ts))
       raise InvalidCommandException("command '{}' is not valid: {}".format(command, err))
 
-  @with_latency_logs()
+    te = time()
+    log.debug("[LATENCY_MEASURE][FINISH][{}][ELAPSED={.8f} seconds]".format('validate_command', te-ts))
+
   def send_command(self, id, command):
+    log.debug("[LATENCY_MEASURE][INIT][{}][command={}]".format('send_command', command))
+    ts = time()
     self._message_protocol.send_msg(COMMAND_SEND_COMMAND)
     self._message_protocol.send_msg(id)
     self._message_protocol.send_msg(command)
@@ -92,7 +88,11 @@ class ClientProtocol:
     if self.__is_valid_response(response_type):
       format = self._message_protocol.receive_msg()
       response = self._message_protocol.receive_msg(decode=False)
+      te = time()
+      log.debug("[LATENCY_MEASURE][FINISH][{}][command={}][ELAPSED={.8f} seconds]".format('send_command', command, te-ts))
       return format, response
     else:
       err = self._message_protocol.receive_msg()
+      te = time()
+      log.debug("[LATENCY_MEASURE][FINISH][{}][command={}][ELAPSED={.8f} seconds]".format('send_command', command, te-ts))
       raise InvalidCommandException("command '{}' for instrument {} is not valid: {}".format(command, id, err))
